@@ -9,9 +9,11 @@ module Language.Haskell.GhclibParserEx.GHC.Hs(
  )
 where
 
-#if defined (GHCLIB_API_HEAD) || defined (GHCLIB_API_902) || defined (GHCLIB_API_900)
+#if defined (GHCLIB_API_HEAD) || defined (GHCLIB_API_904) || defined (GHCLIB_API_902) || defined (GHCLIB_API_900)
 import GHC.Hs
+#  if !defined (GHCLIB_API_HEAD)
 import GHC.Unit.Module
+#  endif
 import GHC.Types.SrcLoc
 #elif defined (GHCLIB_API_810)
 import GHC.Hs
@@ -23,7 +25,7 @@ import Module
 import SrcLoc
 #endif
 
-#if defined (GHCLIB_API_HEAD) || defined (GHCLIB_API_902) || defined (GHCLIB_API_900)
+#if defined (GHCLIB_API_904) || defined (GHCLIB_API_902) || defined (GHCLIB_API_900)
 modName :: Located HsModule -> String
 #else
 modName :: Located (HsModule GhcPs) -> String
