@@ -14,9 +14,15 @@ module Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp(
   )
 where
 
-#if defined (GHCLIB_API_HEAD) || defined(GHCLIB_API_902) || defined (GHCLIB_API_900)
+#if defined (GHCLIB_API_HEAD)
+import GHC.Hs.Extension (GhcPs)
+#endif
+
+#if defined (GHCLIB_API_HEAD) || defined (GHCLIB_API_904) || defined(GHCLIB_API_902) || defined (GHCLIB_API_900)
 import GHC.Hs.ImpExp
+#  if !defined (GHCLIB_API_HEAD)
 import GHC.Types.Name.Reader
+#  endif
 #elif defined (GHCLIB_API_810)
 import GHC.Hs.ImpExp
 import RdrName
@@ -25,7 +31,11 @@ import HsImpExp
 import RdrName
 #endif
 
+#if defined (GHCLIB_API_HEAD)
+isPatSynIE :: IEWrappedName GhcPs -> Bool
+#else
 isPatSynIE :: IEWrappedName RdrName -> Bool
+#endif
 isPatSynIE IEPattern{} = True
 isPatSynIE _ = False
 
